# PyEEM

[![license](https://img.shields.io/github/license/mashape/apistatus.svg)](https://github.com/drewmee/PyEEM/blob/master/LICENSE)
[![CircleCI](https://circleci.com/gh/drewmee/PyEEM.svg?style=shield&circle-token=ccdb16078dcb8ee4e4c9b923f547fc7cb2742aae)](https://app.circleci.com/pipelines/github/drewmee/PyEEM)
[![Read the Docs](https://readthedocs.org/projects/drewmee-demo/badge/?version=latest)](https://pyeem.readthedocs.io/)
<!--- Badge for supported python versions https://img.shields.io/pypi/pyversions/pyeem -->
<!--- Badge for PyPI package https://img.shields.io/pypi/v/pyeem -->
<!--- Badge for codecov -->

Python library for the preprocessing, analysis, and visualization of Excitation Emission Matrices (EEMs).

## Installation

Install via pip:

    $ pip install pyeem [--upgrade]

## Documentation

  Full documentation can be found [here](https://pyeem.readthedocs.io/).

## Dependencies for Local Development

If you wish to build the local documentation or run unit tests, there are a few additional dependencies that are required including:

pip install -e ".[docs, tests]"

## License

This library is licensed under the MIT license. The full text of the license can be found in this repository at LICENSE.txt.